# arpes.endstations.plugin package

## Submodules

  - [arpes.endstations.plugin.ALG\_main
    module](arpes.endstations.plugin.ALG_main)
  - [arpes.endstations.plugin.ALG\_spin\_ToF
    module](arpes.endstations.plugin.ALG_spin_ToF)
  - [arpes.endstations.plugin.ANTARES
    module](arpes.endstations.plugin.ANTARES)
  - [arpes.endstations.plugin.HERS
    module](arpes.endstations.plugin.HERS)
  - [arpes.endstations.plugin.MAESTRO
    module](arpes.endstations.plugin.MAESTRO)
  - [arpes.endstations.plugin.MBS module](arpes.endstations.plugin.MBS)
  - [arpes.endstations.plugin.SToF\_DLD
    module](arpes.endstations.plugin.SToF_DLD)
  - [arpes.endstations.plugin.igor\_export
    module](arpes.endstations.plugin.igor_export)
  - [arpes.endstations.plugin.kaindl
    module](arpes.endstations.plugin.kaindl)
  - [arpes.endstations.plugin.merlin
    module](arpes.endstations.plugin.merlin)

## Module contents

Plugins for data loading, we could hook other code in here too, but this
is the only obvious thing that users might want to add a lot of code
around at the moment
